JW Player for Flash

### Example

Thanks for downloading! Below you see a simple embedded example of the JW Player. Copy-paste the source code and put the SWF, JS and FLV file on your site to get started.

### Licensing

The player is licensed under a Creative Commons License. It allows you to use, modify and redistribute the script, but only for noncommercial purposes. For corporate use, please apply for a commercial license.

### Quickstart

The easiest way to get to know the player is by using the setup wizard. Select an example, set the file or playlist you want to play and copy-paste the embed code to your site. If you want to play Youtube content in the player, you also have to copy the yt.swf file along with the player.swf.

If you need any help, please visit our extensive support section, including FAQs, a string of tutorials and a very active support forum.

### Wiki and source code

The developer Wiki contains a wealth of info about the player, including:

1. All supported file formats (and playlists).
2. All supported flashvars (for customizing the player).
3. All supported API calls (for actionscript / javascript interaction).
4. All supported skinning elements (for creating your own graphics).
5. The roadmap with full changelogs for each version.

The source code of all different versions of the player can be found here. You can click a version and download the ZIP files (the links at the bottom).

### Next steps

If you're ready to get professional about online video, check out our additional services, which take your site to the next level:

1. Our AdSolution is a no-nonsense video advertisement network that will increase your traffic and monetize your streams. Sign up for free.
2. Bits on the Run is a hassle-free video CMS that handles the encoding, streaming and tracking of your videos. Sign up for free.